<?php /** @noinspection PhpUndefinedClassInspection */
/**
 * Sharinger for Elementor
 * Social sharing plugin for Elementor
 * Exclusively on https://1.envato.market/sharinger-elementor
 *
 * @encoding        UTF-8
 * @version         1.0.2
 * @copyright       (C) 2018 - 2022 Merkulove ( https://merkulov.design/ ). All rights reserved.
 * @license         Envato License https://1.envato.market/KYbje
 * @contributors    Cherviakov Vlad (vladchervjakov@gmail.com), Nemirovskiy Vitaliy (nemirovskiyvitaliy@gmail.com), Dmytro Merkulov (dmitry@merkulov.design)
 * @support         help@merkulov.design
 **/

namespace Merkulove\SharingerElementor;

/** Exit if accessed directly. */
if ( ! defined( 'ABSPATH' ) ) {
    header( 'Status: 403 Forbidden' );
    header( 'HTTP/1.1 403 Forbidden' );
    exit;
}

use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Icons_Manager;
use Elementor\Utils;
use Exception;
use Elementor\Widget_Base;
use Elementor\Controls_Manager;
use Elementor\Repeater;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Css_Filter;
use Merkulove\SharingerElementor\Unity\Plugin as UnityPlugin;

/** @noinspection PhpUnused */
/**
 * Sharinger - Custom Elementor Widget.
 **/
class sharinger_elementor extends Widget_Base {

    /**
     * Widget base constructor.
     * Initializing the widget base class.
     *
     * @access public
     * @throws Exception If arguments are missing when initializing a full widget instance.
     * @param array      $data Widget data. Default is an empty array.
     * @param array|null $args Optional. Widget default arguments. Default is null.
     *
     * @return void
     **/
    public function __construct( $data = [], $args = null ) {

        parent::__construct( $data, $args );

        wp_register_style( 'mdp-sharinger-elementor-admin', UnityPlugin::get_url() . 'src/Merkulove/Unity/assets/css/elementor-admin' . UnityPlugin::get_suffix() . '.css', [], UnityPlugin::get_version() );
        wp_register_style( 'mdp-sharinger-elementor', UnityPlugin::get_url() . 'css/sharinger-elementor' . UnityPlugin::get_suffix() . '.css', [], UnityPlugin::get_version() );
	    wp_register_script( 'mdp-sharinger-elementor', UnityPlugin::get_url() . 'js/sharinger-elementor' . UnityPlugin::get_suffix() . '.js', [ 'jquery' ], UnityPlugin::get_version(), true );

    }

    /**
     * @var array
     */
    private static $networks = [
        'facebook' => [
            'title' => 'Facebook',
            'has_counter' => true,
        ],
        'twitter' => [
            'title' => 'Twitter',
        ],
        'pinterest' => [
            'title' => 'Pinterest',
        ],
        'linkedin' => [
            'title' => 'LinkedIn',
            'has_counter' => true,
        ],
        'reddit' => [
            'title' => 'Reddit',
            'has_counter' => true,
        ],
        'tumblr' => [
            'title' => 'Tumblr',
        ],
        'digg' => [
            'title' => 'Digg',
        ],
        'skype' => [
            'title' => 'Skype',
        ],
        'stumbleupon' => [
            'title' => 'StumbleUpon',
            'has_counter' => true,
        ],
        'telegram' => [
            'title' => 'Telegram',
        ],
        'pocket' => [
            'title' => 'Pocket',
            'has_counter' => true,
        ],
        'xing' => [
            'title' => 'XING',
            'has_counter' => true,
        ],
        'whatsapp' => [
            'title' => 'WhatsApp',
        ],
        'email' => [
            'title' => 'Email',
        ],
        'print' => [
            'title' => 'Print',
        ],
    ];

    /**
     * @var \string[][]
     */
    private static $networks_class_dictionary = [
        'pocket' => [
            'value' => 'fa fa-get-pocket',
        ],
        'email' => [
            'value' => 'fa fa-envelope',
        ],
    ];

    /**
     * @var \string[][]
     */
    private static $networks_icon_mapping = [
        'pocket' => [
            'value' => 'fab fa-get-pocket',
            'library' => 'fa-brands',
        ],
        'email' => [
            'value' => 'fas fa-envelope',
            'library' => 'fa-solid',
        ],
        'print' => [
            'value' => 'fas fa-print',
            'library' => 'fa-solid',
        ],
    ];

    /**
     * @param $network_name
     * @return mixed|string[]
     */
    private static function get_network_icon_data( $network_name ) {
        $prefix = 'fa ';
        $library = '';

        if ( Icons_Manager::is_migration_allowed() ) {
            if ( isset( self::$networks_icon_mapping[ $network_name ] ) ) {
                return self::$networks_icon_mapping[ $network_name ];
            }
            $prefix = 'fab ';
            $library = 'fa-brands';
        }
        if ( isset( self::$networks_class_dictionary[ $network_name ] ) ) {
            return self::$networks_class_dictionary[ $network_name ];
        }

        return [
            'value' => $prefix . 'fa-' . $network_name,
            'library' => $library,
        ];
    }

    /**
     * Return a widget name.
     *
     * @return string
     **/
    public function get_name() {

        return 'mdp-sharinger-elementor';

    }

    /**
     * Return the widget title that will be displayed as the widget label.
     *
     * @return string
     **/
    public function get_title() {

        return esc_html__( 'Sharinger', 'sharinger-elementor' );

    }

    /**
     * Set the widget icon.
     *
     * @return string
     */
    public function get_icon() {

        return 'mdp-sharinger-elementor-widget-icon';

    }

    /**
     * Set the category of the widget.
     *
     * @return array with category names
     **/
    public function get_categories() {

        return [ 'general' ];

    }

    /**
     * Get widget keywords. Retrieve the list of keywords the widget belongs to.
     *
     * @access public
     *
     * @return array Widget keywords.
     **/
    public function get_keywords() {

        return [ 'Merkulove', 'Sharinger', 'social', 'sharing', 'share', 'icon', 'button', 'like' ];

    }

    /**
     * Get style dependencies.
     * Retrieve the list of style dependencies the widget requires.
     *
     * @access public
     *
     * @return array Widget styles dependencies.
     **/
    public function get_style_depends() {

        return [
            'elementor-icons-fa-solid',
            'elementor-icons-fa-brands',
            'mdp-sharinger-elementor'
        ];

    }

	/**
	 * Get script dependencies.
	 * Retrieve the list of script dependencies the element requires.
	 *
	 * @access public
     *
	 * @return array Element scripts dependencies.
	 **/
	public function get_script_depends() {

		return [ 'mdp-sharinger-elementor' ];

    }

    /**
     * Add the widget controls.
     *
     * @access protected
     * @return void with category names
     **/
    protected function register_controls() {

        /** Content Tab. */
        $this->share_button_content();

        /** Style Tab. */
        $this->share_button_style();

    }

    /**
     * Share button content
     * @return void
     */
    private function share_button_content() {

        $this->start_controls_section(
            'section_buttons_content',
            [
                'label' => esc_html__( 'Share Buttons', 'sharinger-elementor' ),
            ]
        );

        $repeater = new Repeater();

        $networks = self::$networks;

        $networks_names = array_keys( $networks );

        $repeater->add_control(
            'button',
            [
                'label' => esc_html__( 'Network', 'sharinger-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => array_reduce( $networks_names, function( $options, $network_name ) use ( $networks ) {
                    $options[ $network_name ] = $networks[ $network_name ]['title'];

                    return $options;
                }, [] ),
                'default' => 'facebook',
            ]
        );

        $repeater->add_control(
            'text',
            [
                'label' => esc_html__( 'Custom Label', 'sharinger-elementor' ),
                'type' => Controls_Manager::TEXT,
                'dynamic' => [
                    'active' => true,
                ],
            ]
        );

        $this->add_control(
            'share_buttons',
            [
                'type' => Controls_Manager::REPEATER,
                'fields' => $repeater->get_controls(),
                'default' => [
                    [
                        'button' => 'facebook',
                    ],
                    [
                        'button' => 'twitter',
                    ],
                    [
                        'button' => 'linkedin',
                    ],
                ],
                'title_field' => '{{{ button }}}',
            ]
        );

        $this->add_control(
            'share_button_content_alignment',
            [
                'label' => esc_html__( 'Button Content Horizontal Alignment', 'sharinger-elementor' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => esc_html__( 'Left', 'sharinger-elementor' ),
                        'icon' => 'eicon-h-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'sharinger-elementor' ),
                        'icon' => 'eicon-h-align-center',
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Right', 'sharinger-elementor' ),
                        'icon' => 'eicon-h-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-share-btn__text, {{WRAPPER}} .elementor-share-btn__icon' => 'justify-content: {{value}};',
                ],
                'default' => 'center',
                'toggle' => true
            ]
        );

        $this->add_control(
            'share_button_content_vertical_alignment',
            [
                'label' => esc_html__( 'Button Content Vertical Alignment', 'sharinger-elementor' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => esc_html__( 'Top', 'sharinger-elementor' ),
                        'icon' => 'eicon-v-align-top',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'sharinger-elementor' ),
                        'icon' => 'eicon-v-align-middle',
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Bottom', 'sharinger-elementor' ),
                        'icon' => 'eicon-v-align-bottom',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-share-btn__text, {{WRAPPER}} .elementor-share-btn__icon' => 'align-items: {{value}}',
                ],
                'default' => 'center',
                'toggle' => true
            ]
        );

        $this->add_responsive_control(
            'share_buttons_alignment',
            [
                'label' => esc_html__( 'Buttons Alignment', 'sharinger-elementor' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'flex-start' => [
                        'title' => esc_html__( 'Left', 'sharinger-elementor' ),
                        'icon' => 'eicon-h-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'sharinger-elementor' ),
                        'icon' => 'eicon-h-align-center',
                    ],
                    'flex-end' => [
                        'title' => esc_html__( 'Right', 'sharinger-elementor' ),
                        'icon' => 'eicon-h-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .mdp-sharinger' => 'justify-content: {{VALUE}}; justify-items: {{VALUE}};'
                ],
                'default' => 'center',
                'toggle' => true
            ]
        );

        $this->add_control(
            'view',
            [
                'label' => esc_html__( 'View', 'sharinger-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'icon-text' => 'Icon & Text',
                    'icon' => 'Icon',
                    'text' => 'Text',
                ],
                'default' => 'icon-text',
                'separator' => 'before',
                'prefix_class' => 'elementor-share-buttons--view-',
                'render_type' => 'template',
            ]
        );

        $this->add_control(
            'share_button_icon_position',
            [
                'label' => esc_html__( 'Icon position', 'sharinger-elementor' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'before',
                'options' => [
                    'before'  => esc_html__( 'Left', 'sharinger-elementor' ),
                    'after' => esc_html__( 'Right', 'sharinger-elementor' ),
                    'above-left' => esc_html__( 'Top left', 'sharinger-elementor' ),
                    'above-center' => esc_html__( 'Top center', 'sharinger-elementor' ),
                    'above-right' => esc_html__( 'Top right', 'sharinger-elementor' ),
                    'under-left' => esc_html__( 'Bottom left', 'sharinger-elementor' ),
                    'under-center' => esc_html__( 'Bottom center', 'sharinger-elementor' ),
                    'under-right' => esc_html__( 'Bottom right', 'sharinger-elementor' )
                ],
                'condition' => [
                    'view' => 'icon-text'
                ]
            ]
        );

        $this->add_control(
            'show_label',
            [
                'label' => esc_html__( 'Label', 'sharinger-elementor' ),
                'type' => Controls_Manager::SWITCHER,
                'label_on' => esc_html__( 'Show', 'sharinger-elementor' ),
                'label_off' => esc_html__( 'Hide', 'sharinger-elementor' ),
                'default' => 'yes',
                'condition' => [
                    'view' => 'icon-text',
                ],
            ]
        );

        $this->add_control(
            'skin',
            [
                'label' => esc_html__( 'Skin', 'sharinger-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'gradient' => esc_html__( 'Gradient', 'sharinger-elementor' ),
                    'minimal' => esc_html__( 'Minimal', 'sharinger-elementor' ),
                    'framed' => esc_html__( 'Framed', 'sharinger-elementor' ),
                    'boxed' => esc_html__( 'Boxed Icon', 'sharinger-elementor' ),
                    'flat' => esc_html__( 'Flat', 'sharinger-elementor' ),
                ],
                'default' => 'gradient',
                'prefix_class' => 'elementor-share-buttons--skin-',
            ]
        );

        $this->add_control(
            'shape',
            [
                'label' => esc_html__( 'Shape', 'sharinger-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'square' => esc_html__( 'Square', 'sharinger-elementor' ),
                    'rounded' => esc_html__( 'Rounded', 'sharinger-elementor' ),
                    'circle' => esc_html__( 'Circle', 'sharinger-elementor' ),
                ],
                'default' => 'square',
                'prefix_class' => 'elementor-share-buttons--shape-',
            ]
        );

        $this->add_responsive_control(
            'columns',
            [
                'label' => esc_html__( 'Columns', 'sharinger-elementor' ),
                'type' => Controls_Manager::SELECT,
                'default' => '0',
                'options' => [
                    '0' => 'Auto',
                    '1' => '1',
                    '2' => '2',
                    '3' => '3',
                    '4' => '4',
                    '5' => '5',
                    '6' => '6',
                ],
                'prefix_class' => 'elementor-grid%s-',
            ]
        );

        $this->add_control(
            'share_url_type',
            [
                'label' => esc_html__( 'Target URL', 'sharinger-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'current_page' => esc_html__( 'Current Page', 'sharinger-elementor' ),
                    'custom' => esc_html__( 'Custom', 'sharinger-elementor' ),
                ],
                'default' => 'current_page',
                'separator' => 'before',
            ]
        );

        $this->add_control(
            'share_url',
            [
                'label' => esc_html__( 'Link', 'sharinger-elementor' ),
                'type' => Controls_Manager::URL,
                'dynamic' => [
                    'active' => true,
                ],
                'options' => false,
                'placeholder' => esc_html__( 'https://your-link.com', 'sharinger-elementor' ),
                'condition' => [
                    'share_url_type' => 'custom',
                ],
                'show_label' => false,
                'frontend_available' => true,
            ]
        );

        $this->add_control(
            'sharing_button_hover_animation',
            [
                'label' => esc_html__( 'Hover Animation', 'criptopayer-elementor' ),
                'type' => Controls_Manager::HOVER_ANIMATION,
            ]
        );

        $this->end_controls_section();

    }

    /**
     * Share button style
     * @return void
     */
    private function share_button_style() {

        $this->start_controls_section(
            'section_buttons_style',
            [
                'label' => esc_html__( 'Share Buttons', 'sharinger-elementor' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_responsive_control(
            'column_gap',
            [
                'label' => esc_html__( 'Columns Gap', 'sharinger-elementor' ),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'size' => 10,
                ],
                'selectors' => [
                    '{{WRAPPER}}' => '--grid-side-margin: {{SIZE}}{{UNIT}}; --grid-column-gap: {{SIZE}}{{UNIT}}; --grid-row-gap: {{SIZE}}{{UNIT}}',
                    '(tablet) {{WRAPPER}}' => '--grid-side-margin: {{SIZE}}{{UNIT}}; --grid-column-gap: {{SIZE}}{{UNIT}}',
                    '(mobile) {{WRAPPER}}' => '--grid-side-margin: {{SIZE}}{{UNIT}}; --grid-column-gap: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'row_gap',
            [
                'label' => esc_html__( 'Rows Gap', 'sharinger-elementor' ),
                'type' => Controls_Manager::SLIDER,
                'default' => [
                    'size' => 10,
                ],
                'selectors' => [
                    '{{WRAPPER}}' => '--grid-row-gap: {{SIZE}}{{UNIT}}; --grid-bottom-margin: {{SIZE}}{{UNIT}}',
                    '(tablet) {{WRAPPER}}' => '--grid-row-gap: {{SIZE}}{{UNIT}}; --grid-bottom-margin: {{SIZE}}{{UNIT}}',
                    '(mobile) {{WRAPPER}}' => '--grid-row-gap: {{SIZE}}{{UNIT}}; --grid-bottom-margin: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'button_size',
            [
                'label' => esc_html__( 'Button Size', 'sharinger-elementor' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0.5,
                        'max' => 2,
                        'step' => 0.05,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-share-btn' => 'font-size: calc({{SIZE}}{{UNIT}} * 10);',
                ],
            ]
        );

        $this->add_responsive_control(
            'icon_size',
            [
                'label' => esc_html__( 'Icon Size', 'sharinger-elementor' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'em' => [
                        'min' => 0.5,
                        'max' => 4,
                        'step' => 0.1,
                    ],
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'default' => [
                    'unit' => 'em',
                ],
                'tablet_default' => [
                    'unit' => 'em',
                ],
                'mobile_default' => [
                    'unit' => 'em',
                ],
                'size_units' => [ 'em', 'px' ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-share-btn__icon' => '--e-share-buttons-icon-size: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'view!' => 'text',
                ],
            ]
        );

        $this->add_responsive_control(
            'button_height',
            [
                'label' => esc_html__( 'Button Height', 'sharinger-elementor' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'em' => [
                        'min' => 1,
                        'max' => 50,
                        'step' => 0.1,
                    ],
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1
                    ],
                ],
                'default' => [
                    'unit' => 'em',
                ],
                'tablet_default' => [
                    'unit' => 'em',
                ],
                'mobile_default' => [
                    'unit' => 'em',
                ],
                'size_units' => [ 'em', 'px' ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-share-btn' => 'height: {{SIZE}}{{UNIT}};'
                ],
            ]
        );

        $this->add_responsive_control(
            'button_width',
            [
                'label' => esc_html__( 'Button Width', 'sharinger-elementor' ),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'em' => [
                        'min' => 1,
                        'max' => 50,
                        'step' => 0.1,
                    ],
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1
                    ],
                    '%' => [
                        'min' => 1,
                        'max' => 100,
                        'step' => 1
                    ],
                ],
                'default' => [
                    'unit' => 'em',
                ],
                'tablet_default' => [
                    'unit' => 'em',
                ],
                'mobile_default' => [
                    'unit' => 'em',
                ],
                'size_units' => [ 'em', 'px', '%' ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-grid-item' => 'width: {{SIZE}}{{UNIT}};'
                ],
            ]
        );

        $this->add_responsive_control(
            'border_size',
            [
                'label' => esc_html__( 'Border Size', 'sharinger-elementor' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', 'em' ],
                'default' => [
                    'size' => 2,
                ],
                'range' => [
                    'px' => [
                        'min' => 1,
                        'max' => 20,
                    ],
                    'em' => [
                        'max' => 2,
                        'step' => 0.1,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-share-btn' => 'border-width: {{SIZE}}{{UNIT}};',
                ],
                'condition' => [
                    'skin' => [ 'framed', 'boxed' ],
                ],
            ]
        );

        $this->add_control(
            'color_source',
            [
                'label' => esc_html__( 'Color', 'sharinger-elementor' ),
                'type' => Controls_Manager::SELECT,
                'options' => [
                    'official' => esc_html__( 'Official', 'sharinger-elementor' ),
                    'custom' => esc_html__( 'Custom', 'sharinger-elementor' ),
                ],
                'default' => 'official',
                'prefix_class' => 'elementor-share-buttons--color-',
                'separator' => 'before',
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'typography',
                'selector' => '{{WRAPPER}} .elementor-share-btn__title',
                'exclude' => [ 'line_height' ],
                'separator' => 'after'
            ]
        );

        $this->add_responsive_control(
             'share_button_margin',
            [
                'label' => esc_html__( 'Margin', 'sharinger-elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%', 'em'],
                'devices' => ['desktop', 'tablet', 'mobile'],
                'separator' => 'after',
                'selectors' => [
                    "{{WRAPPER}} .elementor-share-btn" => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}} !important;',
                ],
            ]
        );

        $this->add_responsive_control(
            'share_button_icon_spacing',
            [
                'label' => esc_html__( 'Icon Spacing', 'sharinger-elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'devices' => ['desktop', 'tablet', 'mobile'],
                'condition' => [
                    'view' => 'icon-text'
                ],
                'selectors' => [
                    "{{WRAPPER}} .elementor-share-btn__icon" => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'share_button_icon_box_padding',
            [
                'label' => esc_html__( 'Icon box padding', 'sharinger-elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'devices' => ['desktop', 'tablet', 'mobile'],
                'condition' => [
                    'skin' => 'boxed'
                ],
                'selectors' => [
                    "{{WRAPPER}} .elementor-share-btn__icon" => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );


        $this->start_controls_tabs( 'tabs_button_style' );

        $this->start_controls_tab(
            'tab_button_normal',
            [
                'label' => esc_html__( 'Normal', 'sharinger-elementor' ),
            ]
        );

        $this->add_control(
            'primary_color',
            [
                'label' => esc_html__( 'Primary Color', 'sharinger-elementor' ),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}' => '--e-share-buttons-primary-color: {{VALUE}}',
                ],
                'condition' => [
                    'color_source' => 'custom',
                ],
            ]
        );

        $this->add_control(
            'secondary_color',
            [
                'label' => esc_html__( 'Secondary Color', 'sharinger-elementor' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}}' => '--e-share-buttons-secondary-color: {{VALUE}}',
                ],
                'separator' => 'after',
                'condition' => [
                    'color_source' => 'custom',
                    'skin!' => 'framed',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'share_button_normal_border',
                'label' => esc_html__('Border Type', 'sharinger-elementor'),
                'selector' => "{{WRAPPER}} .elementor-share-btn",
            ]
        );

        $this->add_responsive_control(
         'share_button_normal_border_radius',
            [
                'label' => esc_html__( 'Border radius', 'sharinger-elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    "{{WRAPPER}} .elementor-share-btn" => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'share_button_normal_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'sharinger-elementor' ),
                'selector' => "{{WRAPPER}} .elementor-share-btn",
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'tab_button_hover',
            [
                'label' => esc_html__( 'Hover', 'sharinger-elementor' ),
            ]
        );

        $this->add_control(
            'primary_color_hover',
            [
                'label' => esc_html__( 'Primary Color', 'sharinger-elementor' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-share-btn:hover' => '--e-share-buttons-primary-color: {{VALUE}}',
                ],
                'condition' => [
                    'color_source' => 'custom',
                ],
            ]
        );

        $this->add_control(
            'secondary_color_hover',
            [
                'label' => esc_html__( 'Secondary Color', 'sharinger-elementor' ),
                'type' => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-share-btn:hover' => '--e-share-buttons-secondary-color: {{VALUE}}',
                ],
                'separator' => 'after',
                'condition' => [
                    'color_source' => 'custom',
                    'skin!' => 'framed',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Css_Filter::get_type(),
            [
                'name' => 'css_filters_normal',
                'selector' => '{{WRAPPER}} .elementor-share-btn:hover',
            ]
        );

        $this->add_control(
            'share_button_transition',
            [
                'label' => esc_html__( 'Hover transition duration', 'sharinger-elementor' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 's' ],
                'range' => [
                    's' => [
                        'min' => 0.1,
                        'max' => 5,
                        'step' => 0.1,
                    ],
                ],
                'default' => [
                    'unit' => 's',
                    'size' => 0,
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-share-btn' => 'transition: color {{SIZE}}{{UNIT}}, background {{SIZE}}{{UNIT}}, box-shadow {{SIZE}}{{UNIT}}, border-radius {{SIZE}}{{UNIT}}, border {{SIZE}}{{UNIT}}, filter {{SIZE}}{{UNIT}}, stroke {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'share_button_hover_border',
                'label' => esc_html__('Border Type', 'sharinger-elementor'),
                'selector' => "{{WRAPPER}} .elementor-share-btn:hover",
            ]
        );

        $this->add_responsive_control(
            'share_button_hover_border_radius',
            [
                'label' => esc_html__( 'Border radius', 'sharinger-elementor' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    "{{WRAPPER}} .elementor-share-btn:hover" => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'share_button_hover_box_shadow',
                'label' => esc_html__( 'Box Shadow', 'sharinger-elementor' ),
                'selector' => "{{WRAPPER}} .elementor-share-btn:hover",
            ]
        );

        $this->end_controls_tab();

        $this->end_controls_tabs();

        $this->end_controls_section();

    }

    /**
     * Render Frontend Output. Generate the final HTML on the frontend.
     *
     * @access protected
     *
     * @return void
     **/
    protected function render() {

        $settings = $this->get_settings_for_display();

        if ( empty( $settings['share_buttons'] ) ) {
            return;
        }

        $button_classes = 'elementor-share-btn';

        $button_hover_animation_class = sprintf( ' elementor-animation-%s', esc_attr( $settings['sharing_button_hover_animation'] ) );

        $show_text = 'text' === $settings['view'] || 'yes' === $settings['show_label'];
        ?>
        <div class="elementor-grid mdp-sharinger">
            <?php
            $networks_data = self::$networks;

            foreach ( $settings['share_buttons'] as $button ) {
                $network_name = $button['button'];

                // A deprecated network.
                if ( ! isset( $networks_data[ $network_name ] ) ) {
                    continue;
                }

                $social_network_class = ' elementor-share-btn_' . $network_name;
                ?>
                <div class="elementor-grid-item">
                    <div class="<?php echo esc_attr( $button_classes . $social_network_class . $button_hover_animation_class ); ?>" tabindex="0" aria-label="<?php echo sprintf( esc_attr__( 'Share on %s', 'sharinger-elementor' ), esc_attr( $network_name ) ); ?>">
                        <?php if ( 'icon' === $settings['view'] ) : ?>
                            <span class="elementor-share-btn__icon">
								<?php self::render_share_icon( $network_name ); ?>
							</span>
                        <?php endif; ?>
                        <?php if ( $show_text ) : ?>
                            <div class="elementor-share-btn__text">
                                <?php if ( 'icon-text' === $settings['view'] ) : ?>
                                <div class="mdp-sharinger-icon-text-container mdp-sharinger-icon-position-<?php echo esc_attr( $settings['share_button_icon_position'] ) ?>">
                                    <span class="elementor-share-btn__icon">
								        <?php self::render_share_icon( $network_name ); ?>
							        </span>
                                <?php endif; ?>
                                <?php if ( 'yes' === $settings['show_label'] || 'text' === $settings['view'] ) : ?>
                                    <span class="elementor-share-btn__title">
										<?php
                                        echo $button['text'] ? $button['text'] : $networks_data[ $network_name ]['title'];
                                        ?>
									</span>
                                <?php endif; ?>
                                <?php if ( 'icon-text' === $settings['view'] ) : ?>
                                </div>
                                <?php endif; ?>
                            </div>
                        <?php endif; ?>
                    </div>
                </div>
                <?php
            }
            ?>
        </div>
        <?php

    }

    /**
     * @param $network_name
     * @return void
     */
    private static function render_share_icon( $network_name ) {
        $network_icon_data = self::get_network_icon_data( $network_name );

        $icon = sprintf( '<i class="%s" aria-hidden="true"></i>', $network_icon_data['value'] );

        Utils::print_unescaped_internal_string( $icon );
    }

    /**
     * Return link for documentation
     * Used to add stuff after widget
     *
     * @access public
     *
     * @return string
     **/
    public function get_custom_help_url() {

        return 'https://docs.merkulov.design/tag/sharinger';

    }

}
